Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(326)

Unified Diff: net/url_request/url_request_ftp_job.cc

Issue 5384002: net: Remove typedef net::URLRequest URLRequest; (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: review Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/url_request/url_request_ftp_job.cc
diff --git a/net/url_request/url_request_ftp_job.cc b/net/url_request/url_request_ftp_job.cc
index aec8248bc35d52e91cd71aac9e2f970da9907855..c60275ba36730f495ff11f71e0de50e3ca8f0c26 100644
--- a/net/url_request/url_request_ftp_job.cc
+++ b/net/url_request/url_request_ftp_job.cc
@@ -16,7 +16,7 @@
#include "net/url_request/url_request_context.h"
#include "net/url_request/url_request_error_job.h"
-URLRequestFtpJob::URLRequestFtpJob(URLRequest* request)
+URLRequestFtpJob::URLRequestFtpJob(net::URLRequest* request)
: URLRequestJob(request),
ALLOW_THIS_IN_INITIALIZER_LIST(
start_callback_(this, &URLRequestFtpJob::OnStartCompleted)),
@@ -30,7 +30,7 @@ URLRequestFtpJob::~URLRequestFtpJob() {
}
// static
-URLRequestJob* URLRequestFtpJob::Factory(URLRequest* request,
+URLRequestJob* URLRequestFtpJob::Factory(net::URLRequest* request,
const std::string& scheme) {
DCHECK_EQ(scheme, "ftp");
@@ -233,7 +233,7 @@ void URLRequestFtpJob::StartTransaction() {
rv = net::ERR_FAILED;
}
// The transaction started synchronously, but we need to notify the
// URLRequest delegate via the message loop.
MessageLoop::current()->PostTask(FROM_HERE, NewRunnableMethod(
this, &URLRequestFtpJob::OnStartCompleted, rv));
}
@@ -233,7 +233,7 @@ void URLRequestFtpJob::StartTransaction() {
}
// The transaction started synchronously, but we need to notify the
- // URLRequest delegate via the message loop.
+ // net::URLRequest delegate via the message loop.
MessageLoop::current()->PostTask(FROM_HERE, NewRunnableMethod(
this, &URLRequestFtpJob::OnStartCompleted, rv));

Powered by Google App Engine
This is Rietveld 408576698